==> jc-1.4.0.tar.gz: java/awt/image/PixelInterleavedSampleModel.h <==
// public class java.awt.image.PixelInterleavedSampleModel

// class file dependencies
// @dep_class f63d2ba9547ced54 java_awt_image_ComponentSampleModel
// @dep_class d885f517e5230a75 java_awt_image_PixelInterleavedSampleModel
// @dep_class 13d5f247efc49538 java_awt_image_SampleModel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ComponentSampleModel

#include "java/awt/image/ComponentSampleModel.h"

#ifndef _JC_java_awt_image_PixelInterleavedSampleModel_H_
#define _JC_java_awt_image_PixelInterleavedSampleModel_H_

// Forward structure declarations
struct _jc_java_awt_image_SampleModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs	_jc_java_awt_image_PixelInterleavedSampleModel$sub_refs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs	_jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$refs	_jc_java_awt_image_PixelInterleavedSampleModel$refs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$nonrefs	_jc_java_awt_image_PixelInterleavedSampleModel$nonrefs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$object	_jc_java_awt_image_PixelInterleavedSampleModel$object;

typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vmethods	_jc_java_awt_image_PixelInterleavedSampleModel$vmethods;
typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vtable	_jc_java_awt_image_PixelInterleavedSampleModel$vtable;
typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vtype	_jc_java_awt_image_PixelInterleavedSampleModel$vtype;

// Constructors
extern void _jc_java_awt_image_PixelInterleavedSampleModel$method$_init$670047c2e901fe43(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint, jint, jint, jint, struct _jc_int_array *);

// Virtual methods
extern struct _jc_java_awt_image_SampleModel$object *_jc_java_awt_image_PixelInterleavedSampleModel$method$createCompatibleSampleModel$4d1f5a20acb27acd(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint);
extern struct _jc_java_awt_image_SampleModel$object *_jc_java_awt_image_PixelInterleavedSampleModel$method$createSubsetSampleModel$d26aec60d614f8ac(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, struct _jc_int_array *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_PixelInterleavedSampleModel$method_info$createCompatibleSampleModel$4d1f5a20acb27acd;
extern _jc_method _jc_java_awt_image_PixelInterleavedSampleModel$method_info$createSubsetSampleModel$d26aec60d614f8ac;

// Virtual methods structure
struct _jc_java_awt_image_PixelInterleavedSampleModel$vmethods {
	struct _jc_java_awt_image_SampleModel$object	*(*createCompatibleSampleModel$4d1f5a20acb27acd)(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint);
	struct _jc_java_awt_image_SampleModel$object	*(*createSubsetSampleModel$d26aec60d614f8ac)(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, struct _jc_int_array *);
};

// Vtable
struct _jc_java_awt_image_PixelInterleavedSampleModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_SampleModel$vmethods	java_awt_image_SampleModel;
	_jc_java_awt_image_ComponentSampleModel$vmethods	java_awt_image_ComponentSampleModel;
	_jc_java_awt_image_PixelInterleavedSampleModel$vmethods	java_awt_image_PixelInterleavedSampleModel;
};

// Vtype
struct _jc_java_awt_image_PixelInterleavedSampleModel$vtype {
	_jc_type			type;
	_jc_java_awt_image_PixelInterleavedSampleModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_PixelInterleavedSampleModel$refs {
    _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs	java_awt_image_PixelInterleavedSampleModel;
    _jc_java_awt_image_ComponentSampleModel$sub_refs	java_awt_image_ComponentSampleModel;
    _jc_java_awt_image_SampleModel$sub_refs	java_awt_image_SampleModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_PixelInterleavedSampleModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_SampleModel$sub_nonrefs	java_awt_image_SampleModel;
    _jc_java_awt_image_ComponentSampleModel$sub_nonrefs	java_awt_image_ComponentSampleModel;
    _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs	java_awt_image_PixelInterleavedSampleModel;
};

// Object instance structure
struct _jc_java_awt_image_PixelInterleavedSampleModel$object {
	_jc_java_awt_image_PixelInterleavedSampleModel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_PixelInterleavedSampleModel$vtype	*vtype;
	_jc_java_awt_image_PixelInterleavedSampleModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_PixelInterleavedSampleModel$vtype _jc_java_awt_image_PixelInterleavedSampleModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_PixelInterleavedSampleModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_PixelInterleavedSampleModel$class_object;

#endif	/* _JC_java_awt_image_PixelInterleavedSampleModel_H_ */

==> jc-1.4.5.tar.gz: java/awt/image/PixelInterleavedSampleModel.h <==
// public class java.awt.image.PixelInterleavedSampleModel

// class file dependencies
// @dep_class f63d2ba9547ced54 java_awt_image_ComponentSampleModel
// @dep_class d885f517e5230a75 java_awt_image_PixelInterleavedSampleModel
// @dep_class 13d5f247efc49538 java_awt_image_SampleModel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ComponentSampleModel

#include "java/awt/image/ComponentSampleModel.h"

#ifndef _JC_java_awt_image_PixelInterleavedSampleModel_H_
#define _JC_java_awt_image_PixelInterleavedSampleModel_H_

// Forward structure declarations
struct _jc_java_awt_image_SampleModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs	_jc_java_awt_image_PixelInterleavedSampleModel$sub_refs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs	_jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$refs	_jc_java_awt_image_PixelInterleavedSampleModel$refs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$nonrefs	_jc_java_awt_image_PixelInterleavedSampleModel$nonrefs;
typedef struct _jc_java_awt_image_PixelInterleavedSampleModel$object	_jc_java_awt_image_PixelInterleavedSampleModel$object;

typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vmethods	_jc_java_awt_image_PixelInterleavedSampleModel$vmethods;
typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vtable	_jc_java_awt_image_PixelInterleavedSampleModel$vtable;
typedef const struct _jc_java_awt_image_PixelInterleavedSampleModel$vtype	_jc_java_awt_image_PixelInterleavedSampleModel$vtype;

// Constructors
extern void _jc_java_awt_image_PixelInterleavedSampleModel$method$_init$670047c2e901fe43(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint, jint, jint, jint, struct _jc_int_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_image_SampleModel$object *_jc_java_awt_image_PixelInterleavedSampleModel$method$createCompatibleSampleModel$4d1f5a20acb27acd(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_SampleModel$object *_jc_java_awt_image_PixelInterleavedSampleModel$method$createSubsetSampleModel$d26aec60d614f8ac(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, struct _jc_int_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_PixelInterleavedSampleModel$method_info$createCompatibleSampleModel$4d1f5a20acb27acd;
extern _jc_method _jc_java_awt_image_PixelInterleavedSampleModel$method_info$createSubsetSampleModel$d26aec60d614f8ac;

// Virtual methods structure
struct _jc_java_awt_image_PixelInterleavedSampleModel$vmethods {
	struct _jc_java_awt_image_SampleModel$object	*(*createCompatibleSampleModel$4d1f5a20acb27acd)(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_SampleModel$object	*(*createSubsetSampleModel$d26aec60d614f8ac)(_jc_env *, struct _jc_java_awt_image_PixelInterleavedSampleModel$object *, struct _jc_int_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_PixelInterleavedSampleModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_SampleModel$vmethods	java_awt_image_SampleModel;
	_jc_java_awt_image_ComponentSampleModel$vmethods	java_awt_image_ComponentSampleModel;
	_jc_java_awt_image_PixelInterleavedSampleModel$vmethods	java_awt_image_PixelInterleavedSampleModel;
};

// Vtype
struct _jc_java_awt_image_PixelInterleavedSampleModel$vtype {
	_jc_type			type;
	_jc_java_awt_image_PixelInterleavedSampleModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_PixelInterleavedSampleModel$refs {
    _jc_java_awt_image_PixelInterleavedSampleModel$sub_refs	java_awt_image_PixelInterleavedSampleModel;
    _jc_java_awt_image_ComponentSampleModel$sub_refs	java_awt_image_ComponentSampleModel;
    _jc_java_awt_image_SampleModel$sub_refs	java_awt_image_SampleModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_PixelInterleavedSampleModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_SampleModel$sub_nonrefs	java_awt_image_SampleModel;
    _jc_java_awt_image_ComponentSampleModel$sub_nonrefs	java_awt_image_ComponentSampleModel;
    _jc_java_awt_image_PixelInterleavedSampleModel$sub_nonrefs	java_awt_image_PixelInterleavedSampleModel;
};

// Object instance structure
struct _jc_java_awt_image_PixelInterleavedSampleModel$object {
	_jc_java_awt_image_PixelInterleavedSampleModel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_PixelInterleavedSampleModel$vtype	*vtype;
	_jc_java_awt_image_PixelInterleavedSampleModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_PixelInterleavedSampleModel$vtype _jc_java_awt_image_PixelInterleavedSampleModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_PixelInterleavedSampleModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_PixelInterleavedSampleModel$class_object;

#endif	/* _JC_java_awt_image_PixelInterleavedSampleModel_H_ */
